# Joystick plug-in: ジョイスティックプラグイン

ジョイスティックプラグインではトラックボールがゲームパッドを含む、ジョイスティック入力機器からの入力を受け付けます。また、PyGameのjoystick モジュールを使用することで、ボタンや軸操作、トラックボールを含むジョイスティックも使用できます。

## オプションと応答変数

ジョイスティックプラグインは、キーボード応答アイテムと同様に機能します。 詳細については、キーボード応答アイテムのヘルプをご覧ください:

- <http://osdoc.cogsci.nl/3.2/manual/response/keyboard/>

## ボタン番号

使用するジョイスティックやゲームパッドの種類に応じて、異なる数のボタン、軸、トラックボール、ハットスイッチが存在します。どのボタンがどの番号に対応するか事前に調べるようにしてください。

さらに詳しくはこちらをご覧ください:

- <http://osdoc.cogsci.nl/3.2/manual/response/joystick/>
